@@ -3,19 +3,17 @@ from urlparse import urljoin
 from requests import Request, Session
 
 import tutum
-from tutum.api.exceptions import TutumApiError, TutumAuthError
-
+from exceptions import TutumApiError, TutumAuthError
 
 def send_request(method, path, **kwargs):
     json = None
-    url  = urljoin(tutum.base_url, path.strip("/"))
+    url = urljoin(tutum.base_url, path.strip("/"))
     if not url.endswith("/"):
         url = "%s/" % url
     tutum.logger.info("%s %s %s" % (method, url, kwargs))
     # construct headers
     headers = {'Content-Type': 'application/json', 'User-Agent': 'python-tutum/v1.0'}
-    if tutum.user and tutum.apikey:
-        headers['Authorization'] = 'ApiKey %s:%s' % (tutum.user, tutum.apikey)
+    headers.update(tutum.auth.get_auth_header())
     # construct request
     s = Session()
     req = Request(method, url, headers=headers, **kwargs)
